@@ -6,6 +6,7 @@ from pathlib import Path
 import matplotlib.pyplot as plt
 import numpy as np
 import scipy.optimize as opt
+from area_detector_handlers.handlers import AreaDetectorTiffHandler
 from bluesky.callbacks.stream import LiveDispatcher
 from diffpy.pdfgetx import PDFGetter, PDFConfig
 from event_model import RunRouter
@@ -13,8 +14,7 @@ from ophyd.sim import NumpySeqHandler
 
 import pdfstream.units as units
 from pdfstream.callbacks.basic import LiveWaterfall, NumpyExporter
-from pdfstream.servers import CONFIG_DIR, ServerNames
-from pdfstream.servers.base import ServerConfig, find_cfg_file, BaseServer
+from pdfstream.servers.base import ServerConfig, BaseServer
 
 
 class LSQConfig(ConfigParser):
@@ -95,7 +95,7 @@ class LSQServer(BaseServer):
     and save the data and visualize the residual of the decomposition and the PDF data transformed from it."""
 
     def __init__(self, config: LSQServerConfig):
-        super(LSQServer, self).__init__(config.address, prefix=config.prefix)
+        super(LSQServer, self).__init__(config)
         self.subscribe(LSQRunRouter(config))
 
     @classmethod
@@ -114,7 +114,13 @@ class LSQRunRouter(RunRouter):
 
     def __init__(self, config: LSQConfig):
         factory = LSQFactory(config)
-        super(LSQRunRouter, self).__init__([factory], handler_registry={"NPY_SEQ": NumpySeqHandler})
+        super(LSQRunRouter, self).__init__(
+            [factory],
+            handler_registry={
+                "NPY_SEQ": NumpySeqHandler,
+                "AD_TIFF": AreaDetectorTiffHandler
+            }
+        )
 
 
 class LSQFactory:
@@ -313,8 +319,6 @@ class ExporterFactory:
 
 def make_and_run(cfg_file: str = None, test_mode: bool = False):
     """Make and run LSQ server."""
-    if not cfg_file:
-        cfg_file = find_cfg_file(CONFIG_DIR, ServerNames.lsq)
     server = LSQServer.from_cfg_file(cfg_file)
     if not test_mode:
         server.install_qt_kicker()
